# reliontomotools

Complimentary tools for Subtomogram analysis in Relion tomo.


## scripts

```python
warptomo2relion
```

Converts refinement of deformation models, particle poses and CTF paramaters from WARP/M to Relion tomo.


